"use client";
import AppHeader from "@comp/AppHeader/page";
import { useRouter } from "next/navigation";
import React, { useContext, useEffect, useState } from "react";
import SimpleReactValidator from "simple-react-validator";
import Input from "plugins/Input/page";
import { useRef } from "react";
import Buttonbriz from "plugins/Buttonbriz/page";
import CoffeeBrewCard from "@comp/CoffeeBrew/CoffeeBrewCard/page";
import AppContext from "@ctx/AppContext";
import Chapar from "plugins/Chapar";
import { toast } from "react-toastify";
import CoffeeBrewChart from "plugins/Charts/CoffeeBrewChart";

const page = () => {
  const router = useRouter();
  const CTX = useContext(AppContext);
  const coffeeBrewData = CTX.state.coffeeBrewData;

  const [ratio, setRatio] = useState("");
  const [extractionTime, setExtractionTime] = useState("");
  const [finalYield, setFinalYield] = useState("");
  const [, forceUpdate] = useState();

  const validator = useRef(
    new SimpleReactValidator({
      messages: {
        required: "پر کردن این فیلد الزامی میباشد",
      },
      element: (message) => (
        <>
          <div className="text-right px-1 ">
            <small className="text-red-600 t-ig-small  ">{message}</small>
          </div>
        </>
      ),
    })
  );

  const clear = () => {
    setRatio(""), setExtractionTime(""), setFinalYield("");
  };

  const body = {
    ratio,
    extractionTime,
    finalYield,
  };

  const CreateBrew = async () => {
    CTX.setLoading(true);

    if (validator.current.allValid()) {
      try {
        const data = await Chapar.post(
          `${process.env.NEXT_PUBLIC_API_URL}/brew/CoffeeBrew`,
          JSON.stringify(body)
        );
        toast.success(`ادجاست ساخته شد`, {
          position: "bottom-right",
          closeOnClick: true,
        });

        CTX.setLoading(false);
        CTX.GetCoffeeBrewData();
        // clear();
        // validator.current.hideMessages();
      } catch ({ error, status }) {
        toast.error(`${error?.response?.data?.message}`, {
          position: "bottom-right",
          closeOnClick: true,
        });
        CTX.setLoading(false);
      }
    } else {
      toast.error("پرکردن همه ی فیلد ها واجب است", {
        position: "bottom-right",
        autoClose: 2000,
        hideProgressBar: false,
        closeOnClick: true,
        pauseOnHover: true,
        draggable: true,
        progress: undefined,
      });

      validator.current.showMessages();
      forceUpdate(1);
      CTX.setLoading(false);
    }
  };

  useEffect(() => {
    CTX.GetCoffeeBrewData();
  }, []);

  console.log("coffeeBrewData", coffeeBrewData);

  return (
    <>
      {" "}
      <div className="pb-20">
        <AppHeader
          title="ادجاست قهوه"
          sub="مکانیزم ادجاست قهوه"
          // icon1={true}
          // iconName1="PLUS"
          // iconHref1="#"
          // iconEvent1={() => {
          //   CTX.setBottomSheetCreateShiftsOpen(true);
          // }}
          icon2={true}
          iconName2="ARROW"
          iconHref2="#"
          iconEvent2={() => {
            return router.back();
          }}
        />

        <div className="bg-white overflow-hidden p-5 rtl">
          <div className="">
            <Input
              lable=" BCG | گرماژ قهوه "
              id="ratio-id"
              theme={1}
              name="ratio"
              type={"number"}
              value={ratio}
              inputEvent={(e) => {
                setRatio(e.target.value);
                validator.current.showMessageFor("ratio");
              }}
              style="text-right"
              validator={true}
              validatorData={validator.current.message(
                "ratio",
                ratio,
                "required"
              )}
              mt={"5"}
            />
          </div>
          <div className="">
            <Input
              lable=" OEG | زمان عصاره گیری"
              id="extractionTime-id"
              theme={1}
              name="extractionTime"
              type={"number"}
              value={extractionTime}
              inputEvent={(e) => {
                setExtractionTime(e.target.value);
                validator.current.showMessageFor("extractionTime");
              }}
              style="text-right"
              validator={true}
              validatorData={validator.current.message(
                "extractionTime",
                extractionTime,
                "required"
              )}
              mt={"5"}
            />
          </div>
          <div className="">
            <Input
              lable="ET | گرماژ عصاره خروجی"
              id="finalYield-id"
              theme={1}
              name="finalYield"
              type={"number"}
              value={finalYield}
              inputEvent={(e) => {
                setFinalYield(e.target.value);
                validator.current.showMessageFor("finalYield");
              }}
              style="text-right"
              validator={true}
              validatorData={validator.current.message(
                "finalYield",
                finalYield,
                "required"
              )}
              mt={"5"}
            />
          </div>
          <div>
            {" "}
            <Buttonbriz
              title="ثبت"
              color="PRIMARY"
              icon="CHECK"
              buttonEvent={() => CreateBrew()}
            />
          </div>
          <h3 className="text-right px-3 pb-1 font-medium mt-7 text-sm">
            تاریخچه ادجاست ها
          </h3>
          <div className="flex justify-between mt-4">
            <div className=" ">
              <div className=" p-3 rounded-2xl">
                <div className="w-5 p-1 rounded-full bg-[#4bc0c0]"></div>
                <div>
                  <p className="mb-0 text-gray-400 text-[12px] mt-1 font-medium text-center">
                    گرماژ قهوه{" "}
                  </p>
                </div>
              </div>
            </div>

            <div className="w-[2px] h-9 bg-primary-100 opacity-75 mt-4"></div>
            <div className="">
              <div className=" p-3 rounded-2xl">
                <div className="w-5 p-1 rounded-full bg-[#9966ff]"></div>

                <div>
                  <p className="mb-0  text-gray-400 text-[12px] mt-1 font-medium text-center">
                    زمان عصاره گیری{" "}
                  </p>
                </div>
              </div>
            </div>

            <div className="w-[2px] h-9 bg-primary-100 opacity-75 mt-4"></div>
            <div className=" ">
              <div className=" p-3 rounded-2xl">
                <div className="w-5 p-1 rounded-full bg-[#ff9f40]"></div>

                <div>
                  <p className="mb-0  text-gray-400 text-[12px] mt-1 font-medium text-center">
                    گرماژ عصاره خروجی{" "}
                  </p>
                </div>
              </div>
            </div>
          </div>
          <CoffeeBrewChart data={coffeeBrewData?.pastRecipes} />
          <CoffeeBrewCard data={coffeeBrewData?.currentRecipe} last />
          {coffeeBrewData?.pastRecipes?.map((e) => (
            <CoffeeBrewCard data={e} />
          ))}
        </div>
      </div>
    </>
  );
};

export default page;
